/*
 * @Description: 送货单(U9)明细
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-09-29 21:28:37
 */

import { Tag, Tooltip } from 'ant-design-vue';
import { ActionItem, BasicColumn } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';
import { h } from 'vue';
import { useModal } from '/@/components/Modal';
import { CustModalParams } from '/@/api/tigerapi/model/systemModel';
import { useForm } from '/@/components/Form';

const { t } = useI18n();

function _default() {
  const ActionColumn: BasicColumn = {
    width: 180,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right',
  };

  /**
   * @description: 一些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为，必需要有的方法
     * @return {*}
     */
    CreateAction: (type: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 产品绑定工艺路线操作字段自定义按钮，必需要有的方法
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      data.map((x) => {
        // if (x.name == 'handlePause') {
        //   x.onClick = handlePause.bind(null, args, params);
        //   x.color = 'error';
        //   x.tooltip = '暂停';
        // }
        // if (x.name == 'handleStart') {
        //   x.onClick = handleStart.bind(null, args, params);
        //   x.tooltip = '取消暂停';
        // }
        // if (x.name == 'handleRelease') {
        //   x.onClick = handleRelease.bind(null, args, params);
        //   x.tooltip = '下发';
        // }
        // if (x.name == 'handleUnRelease') {
        //   x.onClick = handleUnRelease.bind(null, args, params);
        //   x.tooltip = '取消下发';
        // }
      });
      return data;
    },
    /**
     * @description: 高级表单和详情页面返回主页面的url
     * @return {*}
     */
    GetHomeUrl: (params: {}) => {
      return `/BIZ_U9_ASN/LC/${encodeURI(JSON.stringify({ ID: 'BIZ_U9_ASN', EntityName: 'BIZ_U9_ASN', colSlots: params['colSlots'], crudColSlots: [] }))}`;
    },
    GetBaseColumns: (type: string) => {
      switch (type) {
        case 'BIZ_U9_ASN_DTL':
          return [
            {
              dataIndex: 'ORDER_NO',
              title: '单据号',
              // ifShow: false,
              sorter: true,
              resizable: true,
            },
            // {
            //   dataIndex: 'BATCH_NO',
            //   title: '工单批次号',
            //   ifShow: true,
            //   sorter: true,
            //   resizable: true,
            //   customRender: () => {},
            // },
            {
              dataIndex: 'STATUS',
              title: '状态',
              ifShow: true,
              sorter: true,
              resizable: true,
              customRender: ({ record }) => {
                let color = '';
                let text = '';
                switch (
                  record.STATUS //状态(0Init初始化|1Imported已导入|2Release已下发|3Working生产中|4Paused已暂停|5Closed已关闭)
                ) {
                  case 0:
                    text = '初始化';
                    color = '#8a8a8a';
                    break;
                  case 1:
                    text = '已导入';
                    color = 'blue';
                    break;
                  case 2:
                    text = '已送达';
                    color = 'green';
                    break;
                  case 3:
                    text = '清点中';
                    color = 'orange';
                    break;
                  case 4:
                    text = '上架中';
                    color = 'red';
                    break;
                  case 5:
                    text = '待审核';
                    color = '#e1822c';
                    break;
                  case 6:
                    text = '已完成';
                    color = '#009966';
                    break;
                  case 7:
                    text = '已作废';
                    color = '#CCCCCC';
                    break;
                }
                return h(Tooltip, { title: text }, () => h(Tag, { color: color }, () => text));
              },
            },
            {
              dataIndex: 'SUPP_CODE',
              title: '供应商编码',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'SUPP_NAME',
              title: '供应商名称',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'ORDER_DATE',
              title: '单据日期',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'DELIVERY_DATE',
              title: '送货日期',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'PLANARRIVED_DATE',
              title: '预计送达日期',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'RECEIVER',
              title: '收货人',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'RECEIVE_DATE',
              title: '收货日期',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'REMARK',
              title: '备注',
              ifShow: true,
              sorter: true,
              resizable: true,
            },
          ];
        case 'BIZ_U9_ASN_SN':
          return [
            {
              dataIndex: 'ORDER_NO',
              title: '单据号',
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'LINE_NO',
              title: '单据行号',
              sorter: true,
              resizable: true,
            },
            {
              dataIndex: 'SN',
              title: '条码',
              sorter: true,
              resizable: true,
            },
          ];
      }
    },
    GetSearchForm: (type: string) => {
      switch (type) {
        case 'BIZ_U9_ASN_DTL':
          return [
            {
              field: 'ORDER_NO',
              label: t('单据号'),
              colProps: { span: 8 },
              component: 'Input',
            },
          ];
        case 'BIZ_U9_ASN_SN':
          return [
            {
              field: 'ORDER_NO',
              label: t('单据号'),
              colProps: { span: 8 },
              component: 'Input',
            },
          ];
      };
    },
    GetCrudForm: () => {
      return [];
    },
    KeyFieldValues: (val: string, id: string) => {
      return { ORDER_NO: val };
    },
    GetUseForm: () => {
      return {
        forminfo: useForm({
          labelWidth: 120,
          schemas: [], //woformSchema,
          actionColOptions: {
            span: 24,
          },
          showActionButtonGroup: false,
        }),
      };
    },
    /**
     * @description: 自定义方法
     * @param {string} type
     * @param {array} args
     * @return {*}
     */
    CustFunc: (param: CustModalParams) => {
      // switch (param.cType) {
      //   case 'BIZ_U9_ASN_DTL':
      //     return getWoFns[param.FnName](param) as Promise<any>;
      //     break;
      //   default:
      //     return new Promise((resolve, reject) => {
      //       try {
      //         (e) => {};
      //         resolve(true);
      //       } catch {
      //         reject(false);
      //       } finally {
      //         // args[0][0]({ confirmLoading: false });
      //       }
      //     });
      //   // break;
      // }
    },
    /**
     * @description: 获取多表单插槽列表
     * @return {*}
     */
    GetDtlSlots: (type: string) => {
      let result = [] as any[];
      switch (type) {
        case 'BIZ_MES_WO_BATCH':
          result = [
            {
              name: 'forminfo',
              slots: ['add', 'set'],
              preIcons: { add: 'search|svg', set: 'config|svg' }, //如果是多个表单，增加多个插槽。slots是弹出框按钮的插槽，preIcons是插槽对应的按钮图标
              title: '下发配置',
            },
          ];
          break;
      }
      return result;
    },
    /**
     * @description: 获取模态框应用列表
     * @return {*}
     */
    GetUseModals: () => {
      return {
        useModalData: {
          add: useModal(),
          set: useModal(),
          addRot: useModal(),
          setRot: useModal(),
        },
      };
    },
    /**
     * @description: 弹出选择框选择成功返回方法
     * @param {*} d
     * @param {*} u
     * @return {*}
     */
    GetSelectSuccess: (d, u) => {
      return {
        ROUTE_CODE: d.values['val'],
        // ID: d.values['id'],
        ROT_ID: d.values['id'],
      };
    },
    /**
     * @description: 打开弹出选择框
     * @param {Fn} openItemModal
     * @param {array} args
     * @return {*}
     */
    OpenSelectItem: (openItemModal: Fn, ...args) => {
      const slotName = args[0];
      switch (slotName) {
        case 'addRot':
          break;
      }
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  return [methods, ActionColumn];
}

export default _default;
